licence = 'MIT'
version = '1.1.12'
pythons = '~=3.10'
appname = 'Shortners'
install = ['aiohttp']
clinton = 'Clinton Abraham'
mention = ['url', 'shortner', 'telegram']
profile = 'https://github.com/Clinton-Abraham'

DATA03 = 'Python url shortner'
DATA01 = "clintonabrahamc@gmail.com"
DATA02 = ['Natural Language :: English',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
          'Programming Language :: Python :: 3.13',
          'Programming Language :: Python :: 3.14',
          'Topic :: Software Development :: Libraries',
          'Topic :: Software Development :: Localization',
          'Topic :: Software Development :: User Interfaces',
          'Topic :: Software Development :: Version Control',]




#====================================================================================================

class Shortner:

    async def shortlink(self, recived, **kwargs):
        async with self.seon() as seion:
            param = {'api': self.apis, 'url': recived}
            async with seion.get(self.site, params=param, timeout=self.tims, **kwargs) as oem:
                if oem.status == 200 or oem.status == "success":
                    moones = await oem.json()
                    moonus = moones.get("shortenedUrl", None)
                    return moonus
                else:
                    return None

#====================================================================================================



import re
import aiohttp
import asyncio
from ..scripts import Regexs
from ..scripts import Scripted
from .function01 import Shortner
from .collections import SMessage
from aiohttp import ClientTimeout
#======================================================================================

class Shortners(Shortner):

    def __init__(self, **kwargs):
        self.seon = aiohttp.ClientSession
        self.tims = kwargs.get("timeout", 30)
        self.apis = kwargs.get("api", Scripted.DATA01)
        self.site = kwargs.get("domain", Scripted.DATA02)

#======================================================================================

    async def clinton(self, recived, **kwargs):
        try:
            moonus = await self.shortlink(recived, **kwargs)
            return SMessage(result=moonus, status=200)
        except asyncio.TimeoutError as errors:
            return SMessage(result=recived, status=404, errors=errors)
        except Exception as errors:
            return SMessage(result=recived, status=404, errors=errors)

#======================================================================================

    async def convert(self, recived, **kwargs):
        try:
            moonus = await self.shortlink(recived, **kwargs)
            return SMessage(result=moonus, status=200)
        except asyncio.TimeoutError as errors:
            return SMessage(result=recived, status=404, errors=errors)
        except Exception as errors:
            return SMessage(result=recived, status=404, errors=errors)

#======================================================================================

    async def bulkshort(self, text, wait=1, storage={}):
        alllinks = re.findall(Regexs.DATA01, text)
        for link in alllinks:
            newlink = await self.convert(link)
            storage[link] = newlink.result
            await asyncio.sleep(wait)

        for original, shortened in storage.items():
            text = text.replace(original, shortened)

        return text

#======================================================================================



from setuptools import setup, find_packages
from Shortners import DATA01, DATA02, DATA03
from Shortners import licence, version
from Shortners import pythons, appname
from Shortners import install, clinton
from Shortners import mention, profile

with open("README.md", "r") as mess:
    description = mess.read()

setup(name=appname,
      url=profile,
      author=clinton,
      version=version,
      license=licence,
      keywords=mention,
      description=DATA03,
      classifiers=DATA02,
      author_email=DATA01,
      python_requires=pythons,
      packages=find_packages(),
      install_requires=install,
      long_description=description,
      long_description_content_type="text/markdown")
